@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2016 Alistair Neil <info@dazzleships.net>
+ * Copyright (C) 2009-2017 Alistair Neil <info@dazzleships.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,6 +50,7 @@ public class NodeList {
     private final String filepath;
     private volatile boolean boolAbortActions;
     private final Pattern pattspace = Pattern.compile(" ");
+    private int nooffavs;
 
     public NodeList(String filepath, String exitfavourites, String guardfavouritesfile) {
         this.hmNode = new HashMap<>();
@@ -675,6 +676,7 @@ public class NodeList {
         }
 
         // Populate model
+        nooffavs = 0;
         for (String s : hmNode.keySet()) {
             ni = hmNode.get(s);
             if (ni.isExit() && ni.isHttpSupported() && ni.getCountryCode().contentEquals(abbrv)) {
@@ -682,12 +684,24 @@ public class NodeList {
                 ni.setTestingMessage(LOCAL.getString("textfield_unknown"));
                 // Whitelisting here
                 ni.setFavouriteEnabled(favourites.contains(ni.getIPAddress()));
+                if (ni.isFavourite()) {
+                    nooffavs++;
+                }
                 Object[] rowData = new Object[]{ni};
                 entm.addRow(rowData);
             }
         }
     }
 
+    /**
+     * Get the number of active favourites
+     *
+     * @return number of favs as int
+     */
+    public int getNumberOfFavs() {
+        return nooffavs;
+    }
+
     /**
      * Ensures any threaded actions will terminate themselves
      */
@@ -705,9 +719,11 @@ public class NodeList {
         SimpleFile sf = new SimpleFile(filepath + exitFavouritesFile);
         sf.openBufferedWrite();
         NodeItem ni;
+        nooffavs = 0;
         for (String s : hmNode.keySet()) {
             ni = hmNode.get(s);
             if (ni.isExit() && ni.isFavourite()) {
+                nooffavs++;
                 sf.writeFile(ni.getIPAddress(), 1);
             }
         }
