@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2016 Alistair Neil <info@dazzleships.net>
+ * Copyright (C) 2009-2017 Alistair Neil <info@dazzleships.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,8 +48,7 @@ public class PacFactory {
     private String strDefaultProxy = "";
     private String strDoNotProxy = "";
     private String strActiveCountry;
-    private int intActiveProxyMode = -1;
-    private int intActivePort = -1;
+    private String strActivePacName = "";
     private final Random randgen;
 
     public PacFactory() {
@@ -65,72 +64,23 @@ public class PacFactory {
         return strActiveCountry;
     }
 
-    /**
-     * Rebuilds the active pac if needed due to changes in the patterns files
-     */
-    public void rebuildActivePac() {
-        createPacFile(strActiveCountry, intActivePort, intActiveProxyMode, true);
-    }
-
     /**
      * Create and/or activate a pacfile for a specific country
      *
      * @param isocountry
      * @param port
-     * @param proxymode
-     * @param activate
      */
-    public void createPacFile(String isocountry, int port, int proxymode, boolean activate) {
-
-        intActivePort = port;
-
-        // May have to overrule depending on proxy mode selected
-        switch (proxymode) {
-            case PROXY_DISABLED:
-                if (proxymode == intActiveProxyMode) {
-                    return;
-                }
-                isocountry = "direct";
-                break;
-            case PROXY_ALL:
-                if (proxymode == intActiveProxyMode) {
-                    return;
-                }
-                isocountry = "proxyall";
-                break;
-        }
-
-        intActiveProxyMode = proxymode;
-
-        if (activate) {
-            deleteAllPAC();
-        }
+    public void createPacFile(String isocountry, int port) {
 
         // Generate a pseudo random pac name
         String pacname = createRandomName() + PACFILE_EXT;
         savePACFile(pacname, getPacRules(isocountry, String.valueOf(port)));
-        if (activate) {
-            strActiveCountry = isocountry;
-            setProxyAutoConfigURL("file://" + strPACPath.replace("\\", "/") + pacname);
+        setProxyAutoConfigURL("file://" + strPACPath.replace("\\", "/") + pacname);
+        strActiveCountry = isocountry;
+        if (!strActivePacName.isEmpty()) {
+            this.deletePAC(strActivePacName);
         }
-    }
-
-    /**
-     * Get active proxymode
-     *
-     * @return integer
-     */
-    public int getActiveProxyMode() {
-        return intActiveProxyMode;
-    }
-
-    /**
-     * Get active port
-     *
-     * @return port as an integer
-     */
-    public int getActivePort() {
-        return intActivePort;
+        strActivePacName = pacname;
     }
 
     /**
@@ -414,16 +364,16 @@ public class PacFactory {
      * Generic restore of proxy settings, for ease of use
      *
      */
-    public void restoreProxyPrefs() {
-        restoreGnomeProxyPrefs();
-        restoreKDEProxyPrefs();
+    public void restoreProxyPrefs(boolean resetonfail) {
+        restoreGnomeProxyPrefs(resetonfail);
+        restoreKDEProxyPrefs(resetonfail);
     }
 
     /**
      * Gnome specific restore of proxy settings
      *
      */
-    private void restoreGnomeProxyPrefs() {
+    private void restoreGnomeProxyPrefs(boolean resetonfail) {
 
         SimpleFile sfProxyPrefs;
 
@@ -440,12 +390,12 @@ public class PacFactory {
                         // Restore original settings from file
                         OSFunction.setGnome3Pref("org.gnome.system.proxy", "mode", mode);
                         OSFunction.setGnome3Pref("org.gnome.system.proxy", "autoconfig-url", url);
-                        return;
+                    }
+                } else {
+                    if (resetonfail) {
+                        setGnomeProxyAutoConfigURL(null);
                     }
                 }
-                // Reset to system default settings
-                setGnomeProxyAutoConfigURL(null);
-                deleteGnomeProxyPrefs();
             }
         } catch (Exception ex) {
             Logger.getGlobal().logp(Level.SEVERE, this.getClass().getName(), "restoreGnomeProxyPrefs()", "", ex);
@@ -456,7 +406,7 @@ public class PacFactory {
      * KDE specific restore of proxy settings
      *
      */
-    private void restoreKDEProxyPrefs() {
+    private void restoreKDEProxyPrefs(boolean resetonfail) {
 
         SimpleFile sfProxyPrefs;
 
@@ -469,13 +419,17 @@ public class PacFactory {
                     String url = sfProxyPrefs.readLine();
                     String type = sfProxyPrefs.readLine();
                     sfProxyPrefs.closeFile();
-                    if (url == null || type == null || !SimpleFile.exists(url)) {
+                    if (url != null && type != null) {
+                        if (!SimpleFile.exists(url)) {
+                            url = "";
+                        }
+                        OSFunction.setKDEPref("Proxy Settings", "Proxy Config Script", url);
+                        OSFunction.setKDEPref("Proxy Settings", "ProxyType", type);
+                    }
+                } else {
+                    if (resetonfail) {
                         setKDEProxyAutoConfigURL(null);
-                        deleteKDEProxyPrefs();
-                        return;
                     }
-                    OSFunction.setKDEPref("Proxy Settings", "Proxy Config Script", url);
-                    OSFunction.setKDEPref("Proxy Settings", "ProxyType", type);
                 }
             }
         } catch (Exception ex) {
@@ -596,7 +550,7 @@ public class PacFactory {
     }
 
     /**
-     * Delete spicified pac file
+     * Delete specified pac file
      *
      * @param filename
      * @return boolean true if action successful
