@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2016 Alistair Neil <info@dazzleships.net>
+ * Copyright (C) 2009-2017 Alistair Neil <info@dazzleships.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,7 +38,6 @@ public final class PatternsEditor extends javax.swing.JDialog {
 
     public static final int CANCEL = 0;
     public static final int APPLY = 1;
-    public static final int RESET = 2;
     private final PACTableModel pactm = new PACTableModel();
     private PacFactory pacFactory = null;
     private String strChange = null;
@@ -171,16 +170,14 @@ public final class PatternsEditor extends javax.swing.JDialog {
         }
         pacFactory.setDoNotProxy(jTextDoNotProxy.getText());
         strChange = pactm.toString() + jTextDoNotProxy.getText();
-        if (strSelectedCountry.startsWith(pacFactory.getActiveCountry())) {
-            pacFactory.rebuildActivePac();
-        }
     }
 
     /**
      * This is a check to see if any pattern save are required before exiting
      * the pattern editor
      */
-    private void saveOnExitCheck() {
+    private int saveOnExitCheck() {
+        int result = CANCEL;
         if (jButtonSave.isEnabled()) {
             jComboCountry.hidePopup();
             InfoDialog id = new InfoDialog(parent);
@@ -190,9 +187,11 @@ public final class PatternsEditor extends javax.swing.JDialog {
             strChange = null;
             if (id.getReturnStatus() == InfoDialog.OK) {
                 savePatterns();
+                result = APPLY;
             }
             jButtonSave.setEnabled(isPatternsTableChanged());
         }
+        return result;
     }
 
     /**
@@ -374,11 +373,11 @@ public final class PatternsEditor extends javax.swing.JDialog {
     private void jButtonSaveActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButtonSaveActionPerformed
         savePatterns();
         jButtonSave.setEnabled(isPatternsTableChanged());
+        doClose(APPLY);
     }//GEN-LAST:event_jButtonSaveActionPerformed
 
     private void jButtonCancelActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButtonCancelActionPerformed
-        saveOnExitCheck();
-        doClose(CANCEL);
+        doClose(saveOnExitCheck());
     }//GEN-LAST:event_jButtonCancelActionPerformed
 
     /**
