@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2016 Alistair Neil <info@dazzleships.net>
+ * Copyright (C) 2009-2017 Alistair Neil <info@dazzleships.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -94,7 +94,6 @@ public final class PrefsDialog extends javax.swing.JDialog {
         jTextTorArgs.setText(sp.getString("PREF_TORARGS"));
         jComboLogLev.setSelectedIndex(sp.getInt("PREF_TORLOGLEV"));
         jCheckSafeSocks.setSelected(sp.getBool("PREF_SAFESOCKS"));
-        jCheckWarnUnsafe.setSelected(sp.getBool("PREF_WARNUNSAFE"));
         jCheckTestSocks.setSelected(sp.getBool("PREF_TESTSOCKS"));
         jCheckAvoidDisk.setSelected(sp.getBool("PREF_AVOIDDISK"));
         jCheckSafeLog.setSelected(sp.getBool("PREF_SAFELOG"));
@@ -114,7 +113,6 @@ public final class PrefsDialog extends javax.swing.JDialog {
         sp.setBool("PREF_UPDATECHECK", jCheckAppUpdate.isSelected());
         sp.setBool("PREF_MINONCLOSE", jCheckMinOnClose.isSelected());
         sp.setBool("PREF_SAFESOCKS", jCheckSafeSocks.isSelected());
-        sp.setBool("PREF_WARNUNSAFE", jCheckWarnUnsafe.isSelected());
         sp.setBool("PREF_TESTSOCKS", jCheckTestSocks.isSelected());
         sp.setBool("PREF_AVOIDDISK", jCheckAvoidDisk.isSelected());
         sp.setBool("PREF_SAFELOG", jCheckSafeLog.isSelected());
@@ -167,7 +165,6 @@ public final class PrefsDialog extends javax.swing.JDialog {
         jTextTorBridge = new javax.swing.JTextField();
         jButtonGetBridges = new javax.swing.JButton();
         jCheckSafeSocks = new javax.swing.JCheckBox();
-        jCheckWarnUnsafe = new javax.swing.JCheckBox();
         jLabel12 = new javax.swing.JLabel();
         jCheckTestSocks = new javax.swing.JCheckBox();
         jLabel13 = new javax.swing.JLabel();
@@ -323,9 +320,6 @@ public final class PrefsDialog extends javax.swing.JDialog {
         jCheckSafeSocks.setText(LOCAL.getString("chkbox_safesocks")); // NOI18N
         jCheckSafeSocks.setToolTipText(LOCAL.getString("ttip_safesocks")); // NOI18N
 
-        jCheckWarnUnsafe.setText(LOCAL.getString("chkbox_warnunsafesocks")); // NOI18N
-        jCheckWarnUnsafe.setToolTipText(LOCAL.getString("ttip_warnunsafe")); // NOI18N
-
         jLabel12.setText(LOCAL.getString("label_torlogging")); // NOI18N
 
         jCheckTestSocks.setText(LOCAL.getString("chkbox_testsocks")); // NOI18N
@@ -366,8 +360,6 @@ public final class PrefsDialog extends javax.swing.JDialog {
                     .addGroup(jPanelTorPrefsLayout.createSequentialGroup()
                         .addComponent(jCheckSafeSocks)
                         .addGap(18, 18, 18)
-                        .addComponent(jCheckWarnUnsafe)
-                        .addGap(18, 18, 18)
                         .addComponent(jCheckTestSocks))
                     .addComponent(jCheckAvoidDisk)
                     .addGroup(jPanelTorPrefsLayout.createSequentialGroup()
@@ -402,7 +394,6 @@ public final class PrefsDialog extends javax.swing.JDialog {
                 .addGroup(jPanelTorPrefsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                     .addComponent(jLabel14)
                     .addComponent(jCheckSafeSocks)
-                    .addComponent(jCheckWarnUnsafe)
                     .addComponent(jCheckTestSocks))
                 .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                 .addGroup(jPanelTorPrefsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
@@ -593,7 +584,6 @@ public final class PrefsDialog extends javax.swing.JDialog {
     private javax.swing.JCheckBox jCheckSafeLog;
     private javax.swing.JCheckBox jCheckSafeSocks;
     private javax.swing.JCheckBox jCheckTestSocks;
-    private javax.swing.JCheckBox jCheckWarnUnsafe;
     private javax.swing.JComboBox<String> jComboLogLev;
     private javax.swing.JLabel jLabel11;
     private javax.swing.JLabel jLabel12;
