@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2016 Alistair Neil <info@dazzleships.net>
+ * Copyright (C) 2009-2017 Alistair Neil <info@dazzleships.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,7 +27,10 @@ import java.net.Socket;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.Iterator;
 import java.util.List;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.logging.Level;
 import java.util.logging.Logger;
@@ -49,11 +52,13 @@ public class TorController extends TorProcess {
     public static final int EVENT_CIRCUIT_FAILED = 18;
     public static final int EVENT_LATENCY_DONE = 19;
     public static final int EVENT_TESTING_DONE = 20;
-    public static final int EVENT_ABORTED = 21;
+    public static final int EVENT_CIRCUIT_CHANGED = 21;
+    public static final int EVENT_ABORTED = 22;
+    private static final String LOCALHOST = "127.0.0.1";
     private static final String[] EVENTMESSAGES = new String[]{
         "EVENT_CIRCUITS_BUILT", "EVENT_CIRCUITS_FAILED", "EVENT_CIRCUIT_BUILT",
         "EVENT_CIRCUIT_FAILED", "EVENT_LATENCY_DONE", "EVENT_TESTING_DONE",
-        "EVENT_ABORTED"
+        "EVENT_CIRCUIT_CHANGED", "EVENT_ABORTED"
     };
 
     // Status constants
@@ -464,7 +469,7 @@ public class TorController extends TorProcess {
                 sockProxy.setSoTimeout(timeout);
                 dis = new DataInputStream(sockProxy.getInputStream());
                 long lngStart = System.currentTimeMillis();
-                dis.read();
+                dis.skipBytes(1);
                 lngResult = System.currentTimeMillis() - lngStart;
             }
         } catch (IOException ex) {
@@ -496,26 +501,31 @@ public class TorController extends TorProcess {
     public void closeCircuitsExcept(String id, boolean filtered) {
         Logger.getGlobal().logp(Level.FINEST, TorController.class.getName(),
                 "closeCircuitsExcept() Port=" + getListenPort(), "");
-        ArrayList<TorCircuit> al = getBuiltCircuits(filtered);
+        Set keys = getBuiltCircuits(filtered).keySet();
+        Iterator i = keys.iterator();
         String hopid;
-        for (TorCircuit tc : al) {
-            hopid = tc.getID();
+        while (i.hasNext()) {
+            hopid = (String) i.next();
             if (!hopid.contentEquals(id)) {
                 closeCircuit(hopid);
             }
         }
     }
 
-    public void closeActiveStreams(String reason) {
-        alActiveStreams = getInfo("stream-status");
-        alActiveStreams.remove("250 OK");
-        Pattern pat = Pattern.compile(" ");
+    private String getCircuitIdFromStream(String stream) {
         String data[];
-        for (String s : alActiveStreams) {
-            data = pat.split(s);
-            sendCommand("CLOSESTREAM " + data[0] + " " + reason);
-        }
-        alActiveStreams.clear();
+        Pattern pat = Pattern.compile(" ");
+        data = pat.split(stream);
+        return data[2];
+    }
+
+    /**
+     * Get list of active streams
+     *
+     * @return active streams as a list
+     */
+    public final ArrayList<String> getActiveStreams() {
+        return alActiveStreams;
     }
 
     /**
@@ -697,18 +707,17 @@ public class TorController extends TorProcess {
                 chmUseableCircuits.clear();
                 break;
             }
-            TorCircuit tc = getActiveCircuit(null);
+            TorCircuit tc = getLatestCircuit();
             if (tc != null) {
                 // If we have a node request then ensure that the circuit contains the requested node fingerprint
                 if (reqFinger != null && !reqFinger.contains(tc.getExit(TorCircuit.FINGER))) {
                     continue;
                 }
                 // If we have custom guards, then ensure circuit contains guard
-                String hops = tc.getHops();
                 if (entrynodes.isEmpty()) {
-                    chmUseableCircuits.put(hops, tc);
+                    chmUseableCircuits.put(tc.getID(), tc);
                 } else if (entrynodes.contains(tc.getGuard(TorCircuit.FINGER))) {
-                    chmUseableCircuits.put(hops, tc);
+                    chmUseableCircuits.put(tc.getID(), tc);
                 }
             }
 
@@ -738,11 +747,11 @@ public class TorController extends TorProcess {
                 chmUseableCircuits.clear();
                 break;
             }
-            TorCircuit tcActive = getActiveCircuit(null);
+            TorCircuit tcActive = getLatestCircuit();
             if (tcActive != null) {
                 String hops = tcActive.getHops();
                 if (hops.contains(reqHops)) {
-                    chmUseableCircuits.put(hops, tcActive);
+                    chmUseableCircuits.put(tcActive.getID(), tcActive);
                 }
             }
         }
@@ -775,16 +784,16 @@ public class TorController extends TorProcess {
                     return null;
                 }
                 if (chmUseableCircuits.size() > 0) {
-                    String hop = chmUseableCircuits.keys().nextElement();
+                    String id = chmUseableCircuits.keys().nextElement();
+                    TorCircuit tc = chmUseableCircuits.get(id);
                     closeCircuitsExcept("", true);
-                    activateCircuitBlocking(hop);
+                    activateCircuitBlocking(tc.getHops());
                     publish(EVENT_CIRCUIT_BUILT);
                     long latency = getTorLatency(5000);
                     if (latency < bestLatency) {
                         bestLatency = latency;
-                        bestHops = (String) hop;
+                        bestHops = tc.getHops();
                     }
-                    closeActiveStreams("done testing");
                 }
                 return null;
             }
@@ -839,10 +848,10 @@ public class TorController extends TorProcess {
      * Get built circuits
      *
      * @param filtered Filter out unwanted circuits
-     * @return ArrayList of built circuits
+     * @return HashMap of built circuits keyed to their circuit id
      */
-    public final ArrayList<TorCircuit> getBuiltCircuits(boolean filtered) {
-        ArrayList<TorCircuit> result = new ArrayList<>();
+    public final HashMap<String, TorCircuit> getBuiltCircuits(boolean filtered) {
+        HashMap<String, TorCircuit> hm = new HashMap<>();
         ArrayList<String> circuits = getInfo("circuit-status");
         circuits.remove("250 OK");
         for (String circuit : circuits) {
@@ -857,19 +866,16 @@ public class TorController extends TorProcess {
                     if (!circuit.contains("PURPOSE=GENERAL")) {
                         continue;
                     }
-                    result.add(new TorCircuit(circuit));
-                    // Debug purposes
-                    //                   if (getListenPort() == 9054) {
-                    //                      System.out.println("Circuit=" + circuit);
-                    //                  }
                 }
+                TorCircuit tc = new TorCircuit(circuit);
+                hm.put(tc.getID(), tc);
+                // Debug purposes
+                //               if (getListenPort() == 9054) {
+                //                   System.out.println("Circuit=" + circuit);
+                //              }
             }
         }
-        // Debug purposes
-        // if (getListenPort() == 9054) {
-        //          System.out.println("***********");
-        //      }
-        return result;
+        return hm;
     }
 
     /**
@@ -883,35 +889,24 @@ public class TorController extends TorProcess {
     }
 
     /**
-     * Get number of active streams
+     * Get the latest circuit
      *
-     * @return number of streams as integer
+     * @return circuit
      */
-    public final int getActiveStreams() {
-        return alActiveStreams.size();
-    }
+    public final TorCircuit getLatestCircuit() {
 
-    /**
-     * Get the currently active node fingerprint
-     *
-     * @param al
-     * @return active node fingerprint
-     */
-    public final TorCircuit getActiveCircuit(ArrayList<TorCircuit> al) {
-
-        if (al == null) {
-            al = getBuiltCircuits(true);
-        }
-        if (al.isEmpty()) {
-            return null;
-        }
-        int hid = 0;
+        HashMap<String, TorCircuit> hm = getBuiltCircuits(true);
+        Iterator i = getBuiltCircuits(true).keySet().iterator();
+        String strId;
         TorCircuit tcRecent = null;
-        for (TorCircuit tc : al) {
-            int id = Integer.parseInt(tc.getID());
+        int hid = 0;
+        int id;
+        while (i.hasNext()) {
+            strId = (String) i.next();
+            id = Integer.parseInt(strId);
             if (id > hid) {
                 hid = id;
-                tcRecent = tc;
+                tcRecent = hm.get(strId);
             }
         }
         return tcRecent;
@@ -919,12 +914,11 @@ public class TorController extends TorProcess {
 
     private void openControlSocket() {
         try {
-            sockControl = new Socket(getListenAddress(), getControlPort());
+            sockControl = new Socket(LOCALHOST, getControlPort());
             sockControl.setKeepAlive(true);
             sockControl.setSoTimeout(2000);
             pwSocket = new PrintWriter(sockControl.getOutputStream());
             brSocket = new BufferedReader(new InputStreamReader(sockControl.getInputStream()), 1024);
-
         } catch (IOException ex) {
             Logger.getGlobal().throwing(TorController.class
                     .getName(),
@@ -1099,7 +1093,7 @@ public class TorController extends TorProcess {
                         break;
                 }
             }
-            return createSocks4aSocket(getListenAddress(), getListenPort(), host, port);
+            return createSocks4aSocket(LOCALHOST, getListenPort(), host, port);
 
         } catch (URISyntaxException ex) {
             Logger.getLogger(TorController.class
