@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2016 Alistair Neil <info@dazzleships.net>
+ * Copyright (C) 2009-2017 Alistair Neil <info@dazzleships.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -72,7 +72,6 @@ public class TorProcess extends ClientProcess {
     private final String strClientLocation;
     private final String strConfigFolder;
     private String strSecret;
-    private String strListenAddress;
     private String strCachedDataFolder;
     private String invCommas = "\"";
     private String strExternalArgs = "";
@@ -130,16 +129,6 @@ public class TorProcess extends ClientProcess {
         super.start(strConfig);
     }
 
-    /**
-     * Set the listen address
-     *
-     * @param address
-     */
-    public final void setListenAddress(String address) {
-        strListenAddress = address;
-        setCLIOption("SocksListenAddress", address);
-    }
-
     /**
      * Set the Tor stdout log level
      *
@@ -276,9 +265,6 @@ public class TorProcess extends ClientProcess {
                 if (percent >= 40) {
                     setStartupTimeout(120);
                 }
-                if (percent >= 60) {
-                    setStartupTimeout(180);
-                }
                 if (percent >= 80) {
                     setStartupTimeout(30);
                 }
@@ -634,15 +620,6 @@ public class TorProcess extends ClientProcess {
         return sbResult.toString().trim();
     }
 
-    /**
-     * Get the listening address
-     *
-     * @return listening address as a String
-     */
-    public final String getListenAddress() {
-        return strListenAddress;
-    }
-
     /**
      * Get the listening port
      *
@@ -838,7 +815,7 @@ public class TorProcess extends ClientProcess {
                     strVer = line;
                 }
                 br.close();
-                proc.destroyForcibly();
+                proc.destroy();
                 proc.waitFor();
             } catch (IOException | InterruptedException ex) {
                 Logger.getLogger(TorProcess.class.getName()).log(Level.SEVERE, null, ex);
