@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2016 Alistair Neil <info@dazzleships.net>
+ * Copyright (C) 2009-2017 Alistair Neil <info@dazzleships.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -435,7 +435,7 @@ public class OSFunction {
      * @return String preference value
      */
     public static String getGnome3Pref(String schema, String key) {
-        Process p = launchProcess("gsettings get " + schema + " " + key);
+        Process p = launchProcess("gsettings", "get", schema, key);
         String result = getProcessResult(p);
         if (result != null) {
             result = result.replace("'", "").replace("[", "").replace("]", "");
@@ -451,7 +451,7 @@ public class OSFunction {
      * @param value
      */
     public static void setGnome3Pref(String schema, String key, boolean value) {
-        launchProcess("gsettings set " + schema + " " + key + " '" + String.valueOf(value) + "'");
+        setGnome3Pref(schema, key, String.valueOf(value));
     }
 
     /**
@@ -462,10 +462,10 @@ public class OSFunction {
      * @param value
      */
     public static void setGnome3Pref(String schema, String key, String value) {
-        if (value.isEmpty()) {
-            launchProcess("gsettings set " + schema + " " + key + " ''");
+        if (value == null || value.isEmpty()) {
+            resetGnome3Pref(schema, key);
         } else {
-            launchProcess("gsettings set " + schema + " " + key + " '" + value + "'");
+            launchProcess("gsettings", "set", schema, key, "'" + value + "'");
         }
     }
 
@@ -478,9 +478,9 @@ public class OSFunction {
      */
     public static void resetGnome3Pref(String schema, String key) {
         if (key == null) {
-            launchProcess("gsettings reset " + schema);
+            launchProcess("gsettings", "reset", schema);
         } else {
-            launchProcess("gsettings reset " + schema + " " + key);
+            launchProcess("gsettings", "reset", schema, key);
         }
     }
 
@@ -620,7 +620,11 @@ public class OSFunction {
      */
     public static String getKDEProxyPath() {
         if (isLinux()) {
-            File f = new File(getUsersHomeFolder() + "/.kde/share/config/kioslaverc");
+            File f = new File(getUsersHomeFolder() + "/.config/kioslaverc");
+            if (f.exists()) {
+                return f.getAbsolutePath();
+            }
+            f = new File(getUsersHomeFolder() + "/.kde/share/config/kioslaverc");
             if (f.exists()) {
                 return f.getAbsolutePath();
             }
@@ -690,11 +694,11 @@ public class OSFunction {
      */
     public static Process launchProcess(String... command) {
         try {
-            if (command.length == 1) {
-                return Runtime.getRuntime().exec(command[0]);
-            } else {
-                return Runtime.getRuntime().exec(command);
+            Process p = Runtime.getRuntime().exec(command);
+            if (p == null) {
+                Logger.getGlobal().logp(Level.WARNING, OSFunction.class.getName(), "launchProcess", "Failed Process", "");
             }
+            return p;
         } catch (IOException ex) {
             Logger.getGlobal().logp(Level.WARNING, OSFunction.class.getName(), "launchProcess", "", ex);
         }
@@ -833,7 +837,11 @@ public class OSFunction {
                 result = "kde4";
                 break;
             }
-            if (s.contains("enlightenment")) {
+             if (s.contains("plasmashell")) {
+                result = "kde5";
+                break;
+            }
+           if (s.contains("enlightenment")) {
                 result = "enlightenment";
                 break;
             }
