@@ -18,9 +18,15 @@
 package lib;
 
 import java.io.*;
+import java.nio.file.FileVisitResult;
 import java.nio.file.Files;
 import java.nio.file.Path;
+import java.nio.file.Paths;
+import java.nio.file.SimpleFileVisitor;
 import java.nio.file.StandardCopyOption;
+import java.nio.file.attribute.BasicFileAttributes;
+import java.util.ArrayList;
+import java.util.Date;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.zip.ZipEntry;
@@ -29,7 +35,7 @@ import java.util.zip.ZipOutputStream;
 
 /**
  *
- * @author Alistair Neil <info@dazzleships.net>
+ * @author Alistair Neil info@dazzleships.net
  */
 public class SimpleFile {
 
@@ -63,7 +69,7 @@ public class SimpleFile {
      *
      * @param pathname
      */
-    public void setFileName(String pathname) {
+    public final void setFileName(String pathname) {
         f = new File(pathname);
     }
 
@@ -72,7 +78,7 @@ public class SimpleFile {
      *
      * @param file
      */
-    public void setFile(File file) {
+    public final void setFile(File file) {
         f = file;
     }
 
@@ -81,7 +87,7 @@ public class SimpleFile {
      *
      * @return file
      */
-    public File getFile() {
+    public final File getFile() {
         return f;
     }
 
@@ -89,7 +95,7 @@ public class SimpleFile {
      * Close file and any resources such as buffered readers/writers that are
      * attached to it.
      */
-    public void closeFile() {
+    public final void closeFile() {
         if (br != null) {
             try {
                 br.close();
@@ -113,7 +119,7 @@ public class SimpleFile {
      *
      * @param filter
      */
-    public void setFileFilter(String filter) {
+    public final void setFileFilter(String filter) {
         this.filter = filter;
     }
 
@@ -122,11 +128,11 @@ public class SimpleFile {
      *
      * @return Returns the file filter
      */
-    public String getFileFilter() {
+    public final String getFileFilter() {
         return filter;
     }
 
-    public static String getSeparator() {
+    public final static String getSeparator() {
         return File.separator;
     }
 
@@ -135,7 +141,7 @@ public class SimpleFile {
      *
      * @return True if successful
      */
-    public boolean createFolder() {
+    public final boolean createFolder() {
         if (f.exists()) {
             return true;
         }
@@ -148,7 +154,7 @@ public class SimpleFile {
      * @param path The location of the new folder
      * @return True if successful
      */
-    public static boolean createFolder(String path) {
+    public final static boolean createFolder(String path) {
         File fl = new File(path);
         if (fl.exists()) {
             return true;
@@ -161,7 +167,7 @@ public class SimpleFile {
      *
      * @return True if file exist or is created
      */
-    public boolean createFile() {
+    public final boolean createFile() {
         boolean createNewFile = true;
         if (!f.exists()) {
             try {
@@ -180,7 +186,7 @@ public class SimpleFile {
      *
      * @return An array of Files
      */
-    public File[] getFileList() {
+    public final File[] getFileList() {
 
         File[] arrFilesCache;
         if (filter.isEmpty()) {
@@ -196,12 +202,57 @@ public class SimpleFile {
         return arrFilesCache;
     }
 
+    public final File getOldestFile() {
+        long lngLastAge = new Date().getTime();
+        File oldest = null;
+        File[] arrFiles = getFileList();
+        for (File fi : arrFiles) {
+            if (fi.lastModified() < lngLastAge) {
+                lngLastAge = fi.lastModified();
+                oldest = fi;
+            }
+        }
+        return oldest;
+    }
+
+    public final static void walkFileTree(String path, ArrayList<File> files) {
+        walkFileTree(path, files, "");
+    }
+
+    public final static void walkFileTree(String path, ArrayList<File> files, final String filter) {
+
+        File[] arrFilesCache;
+        File root = new File(path);
+        if (filter.isEmpty()) {
+            arrFilesCache = root.listFiles();
+        } else {
+            arrFilesCache = root.listFiles(new FileFilter() {
+                @Override
+                public boolean accept(File pathname) {
+                    return pathname.getPath().contains(filter);
+                }
+            });
+        }
+
+        if (arrFilesCache == null) {
+            return;
+        }
+
+        for (File f : arrFilesCache) {
+            if (f.isDirectory()) {
+                walkFileTree(f.getAbsolutePath(), files, filter);
+            } else {
+                files.add(f);
+            }
+        }
+    }
+
     /**
      * Deletes the supplied list of files, be very carefull with this
      *
      * @param files
      */
-    public void deleteFileList(File[] files) {
+    public final void deleteFileList(File[] files) {
         for (File fx : files) {
             if (fx.isFile()) {
                 boolean delete = fx.delete();
@@ -215,7 +266,7 @@ public class SimpleFile {
      * @param folder
      * @return boolean True if successful
      */
-    public static boolean deleteFolder(String folder) {
+    public final static boolean deleteFolder(String folder) {
         if (OSFunction.isLinux() && folder.contentEquals("/")) {
             return false;
         }
@@ -245,7 +296,7 @@ public class SimpleFile {
      *
      * @param folder
      */
-    public static void secureWipeFolder(String folder) {
+    public final static void secureWipeFolder(String folder) {
         if (OSFunction.isLinux() && folder.contentEquals("/")) {
             return;
         }
@@ -257,7 +308,7 @@ public class SimpleFile {
      *
      * @param folder
      */
-    public static void secureWipeFolder(File folder) {
+    public final static void secureWipeFolder(File folder) {
         if (!folder.exists()) {
             return;
         }
@@ -277,7 +328,7 @@ public class SimpleFile {
      *
      * @param filename
      */
-    public static void secureWipe(String filename) {
+    public final static void secureWipe(String filename) {
         secureWipe(new File(filename));
     }
 
@@ -286,7 +337,7 @@ public class SimpleFile {
      *
      * @param f
      */
-    public static void secureWipe(File f) {
+    public final static void secureWipe(File f) {
 
         if (!f.exists()) {
             return;
@@ -310,8 +361,10 @@ public class SimpleFile {
             b = new byte[0];
             fos = new FileOutputStream(f, false);
             fos.write(b);
-        } catch (Exception ex) {
-            Logger.getLogger(SimpleFile.class.getName()).log(Level.SEVERE, null, ex);
+
+        } catch (IOException ex) {
+            Logger.getLogger(SimpleFile.class
+                    .getName()).log(Level.SEVERE, null, ex);
         } finally {
             try {
                 if (fos != null) {
@@ -321,12 +374,12 @@ public class SimpleFile {
                 f = renameTo(f, "0000000000");
                 // Delete file
                 f.delete();
-            } catch (Exception ex) {
+            } catch (IOException ex) {
             }
         }
     }
 
-    public static File renameTo(File f, String newname) {
+    public final static File renameTo(File f, String newname) {
         String path = f.getParent();
         if (path != null) {
             path += File.separator + newname;
@@ -345,7 +398,7 @@ public class SimpleFile {
      * @param to The to path
      * @param ignore
      */
-    public static void copyFolderContents(String from, String to, String ignore) {
+    public final static void copyFolderContents(String from, String to, String ignore) {
         try {
             File ourFile = new File(from);
             for (File fx : ourFile.listFiles()) {
@@ -365,7 +418,7 @@ public class SimpleFile {
      * @param offset
      * @return An array of filenames
      */
-    public String[] getFilenames(int offset) {
+    public final String[] getFilenames(int offset) {
 
         String filename;
         File[] fileList = getFileList();
@@ -387,7 +440,7 @@ public class SimpleFile {
      *
      * @return Returns true if file exists
      */
-    public boolean exists() {
+    public final boolean exists() {
         return f.exists();
     }
 
@@ -397,7 +450,7 @@ public class SimpleFile {
      * @param pathname The pathname to check for
      * @return Returns true if file exists
      */
-    public static boolean exists(String pathname) {
+    public final static boolean exists(String pathname) {
         return new File(pathname).exists();
     }
 
@@ -406,7 +459,7 @@ public class SimpleFile {
      *
      * @return Returns true if successful
      */
-    public boolean delete() {
+    public final boolean delete() {
         return f.delete();
     }
 
@@ -416,7 +469,7 @@ public class SimpleFile {
      * @param filename
      * @return Returns true if successful
      */
-    public static boolean delete(String filename) {
+    public final static boolean delete(String filename) {
         return new File(filename).delete();
     }
 
@@ -425,28 +478,30 @@ public class SimpleFile {
      * @param toname
      * @return Returns true if successful
      */
-    public boolean renameFile(String toname) {
+    public final boolean renameFile(String toname) {
         return f.renameTo(new File(toname));
     }
 
     /**
      * Opens a buffered file for read
      *
+     * @return Returns null if failed
      */
-    public void openBufferedRead() {
+    public final BufferedReader openBufferedRead() {
 
         try {
             br = new BufferedReader(new FileReader(f));
+            return br;
         } catch (FileNotFoundException ex) {
-            Logger.getGlobal().logp(Level.WARNING, this.getClass().getName(), "openBufferedRead(int filehandle)", "", ex);
         }
+        return null;
     }
 
     /**
      * Use this if you need access to a file within a jar
      *
      */
-    public void openBufferedResource() {
+    public final void openBufferedResource() {
 
         try {
             String path = f.getPath();
@@ -462,7 +517,7 @@ public class SimpleFile {
      * Opens a buffered file for append
      *
      */
-    public void openBufferedAppend() {
+    public final void openBufferedAppend() {
 
         try {
             bw = new BufferedWriter(new FileWriter(f, true));
@@ -476,7 +531,7 @@ public class SimpleFile {
      *
      * @return Contents as String
      */
-    public String readLine() {
+    public final String readLine() {
         try {
             return br.readLine();
         } catch (IOException ex) {
@@ -490,7 +545,7 @@ public class SimpleFile {
      *
      * @return Returns the entire contents from a file
      */
-    public String readEntireFile() {
+    public final String readEntireFile() {
 
         char[] cb = new char[blockreadsize];
         StringBuilder sb = new StringBuilder();
@@ -507,7 +562,7 @@ public class SimpleFile {
         return "";
     }
 
-    public FileInputStream openFileInputStream(String filename) {
+    public final FileInputStream openFileInputStream(String filename) {
         try {
             return new FileInputStream(new File(filename));
         } catch (FileNotFoundException ex) {
@@ -521,7 +576,7 @@ public class SimpleFile {
      *
      * @return Returns Opened file output stream
      */
-    public FileOutputStream openFileOutputStream() {
+    public final FileOutputStream openFileOutputStream() {
         try {
             return new FileOutputStream(f);
         } catch (FileNotFoundException ex) {
@@ -534,7 +589,7 @@ public class SimpleFile {
      * Opens a buffered file for write
      *
      */
-    public void openBufferedWrite() {
+    public final void openBufferedWrite() {
 
         try {
             bw = new BufferedWriter(new FileWriter(f));
@@ -543,7 +598,7 @@ public class SimpleFile {
         }
     }
 
-    public void flushWriter() {
+    public final void flushWriter() {
         try {
             bw.flush();
         } catch (IOException ex) {
@@ -556,7 +611,7 @@ public class SimpleFile {
      * @param data The data to be written
      * @param newlines The number of newlines to generate
      */
-    public void writeFile(String data, int newlines) {
+    public final void writeFile(String data, int newlines) {
 
         try {
             bw.write(data);
@@ -576,7 +631,7 @@ public class SimpleFile {
      * @param data The character data to be written
      * @param nochars
      */
-    public void writeFile(char[] data, int nochars) {
+    public final void writeFile(char[] data, int nochars) {
 
         try {
             bw.write(data, 0, nochars);
@@ -591,7 +646,7 @@ public class SimpleFile {
      * @param frompath
      * @param topath
      */
-    public static void copyFromTo(String frompath, String topath) {
+    public final static void copyFromTo(String frompath, String topath) {
         try {
             Path source = new File(frompath).toPath();
             Path dest = new File(topath).toPath();
@@ -601,7 +656,7 @@ public class SimpleFile {
         }
     }
 
-    public static void mergeFiles(String srcpath1, String srcpath2, String destpath) {
+    public final static void mergeFiles(String srcpath1, String srcpath2, String destpath) {
         try (OutputStream os = new FileOutputStream(new File(destpath))) {
             Path source = new File(srcpath1).toPath();
             Files.copy(source, os);
@@ -620,7 +675,7 @@ public class SimpleFile {
      * @param period
      * @return Age of file as float
      */
-    public static float getAgeOfFile(String filepath, int period) {
+    public final static float getAgeOfFile(String filepath, int period) {
         File fx = new File(filepath);
         if (!fx.exists()) {
             return -1;
@@ -644,7 +699,7 @@ public class SimpleFile {
      * @param minutes
      * @return boolean
      */
-    public static boolean isMinutesOlder(String filename, long minutes) {
+    public final static boolean isMinutesOlder(String filename, long minutes) {
         long lngAge = System.currentTimeMillis() - new File(filename).lastModified();
         return lngAge > (60000 * minutes);
     }
@@ -656,7 +711,7 @@ public class SimpleFile {
      * @param hours
      * @return boolean
      */
-    public static boolean isHoursOlder(String filename, long hours) {
+    public final static boolean isHoursOlder(String filename, long hours) {
         long lngAge = System.currentTimeMillis() - new File(filename).lastModified();
         return lngAge > (60000 * 60 * hours);
     }
@@ -668,7 +723,7 @@ public class SimpleFile {
      * @param days
      * @return boolean
      */
-    public static boolean isDaysOlder(String filename, long days) {
+    public final static boolean isDaysOlder(String filename, long days) {
         long lngAge = System.currentTimeMillis() - new File(filename).lastModified();
         return lngAge > (60000 * 60 * 24 * days);
     }
@@ -679,7 +734,7 @@ public class SimpleFile {
      * @param level
      * @return an open zipstream
      */
-    public boolean openZipStream(int level) {
+    public final boolean openZipStream(int level) {
         try {
             zos = new ZipOutputStream(new FileOutputStream(f.getAbsolutePath()));
             if (level < 0 || level > 9) {
@@ -695,7 +750,7 @@ public class SimpleFile {
     /**
      * Close a zip stream
      */
-    public void closeZipStream() {
+    public final void closeZipStream() {
         if (zos != null) {
             try {
                 zos.close();
@@ -704,13 +759,36 @@ public class SimpleFile {
         }
     }
 
+    public final static void compress(String source, String dest) {
+        final Path pathSource = Paths.get(source);
+        try {
+            final ZipOutputStream outputStream = new ZipOutputStream(new FileOutputStream(dest));
+            Files.walkFileTree(pathSource, new SimpleFileVisitor<Path>() {
+                @Override
+                public FileVisitResult visitFile(Path file, BasicFileAttributes attributes) {
+                    try {
+                        Path targetFile = pathSource.relativize(file);
+                        outputStream.putNextEntry(new ZipEntry(targetFile.toString()));
+                        byte[] bytes = Files.readAllBytes(file);
+                        outputStream.write(bytes, 0, bytes.length);
+                        outputStream.closeEntry();
+                    } catch (IOException e) {
+                    }
+                    return FileVisitResult.CONTINUE;
+                }
+            });
+            outputStream.close();
+        } catch (IOException e) {
+        }
+    }
+
     /**
      * Add files to a zip file
      *
      * @param srcfiles An array of Files
      * @return boolean True if successful
      */
-    public boolean addFilesToZip(File... srcfiles) {
+    public final boolean addFilesToZip(File... srcfiles) {
         FileInputStream in = null;
         if (srcfiles == null || srcfiles.length == 0) {
             return false;
@@ -718,13 +796,10 @@ public class SimpleFile {
         try {
             for (File fx : srcfiles) {
                 in = new FileInputStream(fx);
-                // name the file inside the zip  file
+                // name the file inside the zip file
                 zos.putNextEntry(new ZipEntry(fx.getName()));
-                byte[] b = new byte[2048];
-                int count;
-                while ((count = in.read(b)) > 0) {
-                    zos.write(b, 0, count);
-                }
+                byte[] b = Files.readAllBytes(Paths.get(fx.getAbsolutePath()));
+                zos.write(b, 0, b.length);
                 in.close();
             }
             return true;
@@ -734,7 +809,7 @@ public class SimpleFile {
                 if (in != null) {
                     in.close();
                 }
-            } catch (Exception ex) {
+            } catch (IOException ex) {
             }
         }
         return false;
@@ -746,7 +821,7 @@ public class SimpleFile {
      * @param destpath Destination for contents of zip file
      * @return True if successful
      */
-    public boolean extractZipTo(String destpath) {
+    public final boolean extractZipTo(String destpath) {
         FileOutputStream fos;
         final int BUFFER = 2048;
         try {
@@ -780,4 +855,41 @@ public class SimpleFile {
         return false;
     }
 
+    public final static boolean objectWrite(String filepath, Object o) {
+        ObjectOutputStream oos = null;
+        try {
+            oos = new ObjectOutputStream(new FileOutputStream(new File(filepath)));
+        } catch (FileNotFoundException ex) {
+        } catch (IOException ex) {
+        }
+        if (oos == null) {
+            return false;
+        }
+        try {
+            oos.writeObject(o);
+            oos.close();
+            return true;
+        } catch (IOException ex) {
+        }
+        return false;
+    }
+
+    public final static Object objectRead(String filepath, Object defObject) {
+        ObjectInputStream oos = null;
+        try {
+            oos = new ObjectInputStream(new FileInputStream(new File(filepath)));
+        } catch (FileNotFoundException ex) {
+        } catch (IOException ex) {
+        }
+        if (oos == null) {
+            return defObject;
+        }
+        Object result = defObject;
+        try {
+            result = oos.readObject();
+        } catch (IOException | ClassNotFoundException ex) {
+        }
+        return result;
+    }
+
 }
